summaryrefslogtreecommitdiffstats
path: root/chrome/browser/automation
diff options
context:
space:
mode:
authoravi@chromium.org <avi@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2012-12-13 21:19:55 +0000
committeravi@chromium.org <avi@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2012-12-13 21:19:55 +0000
commit1f2469ad4fad18c59abe6f7b721b3044a673b7d3 (patch)
treedc376f16a854fc3a28f4cc96a11efd6f820c9bcc /chrome/browser/automation
parent653dc10d5b6a0e7852a228e4b124e2b1a82b1d6c (diff)
downloadchromium_src-1f2469ad4fad18c59abe6f7b721b3044a673b7d3.zip
chromium_src-1f2469ad4fad18c59abe6f7b721b3044a673b7d3.tar.gz
chromium_src-1f2469ad4fad18c59abe6f7b721b3044a673b7d3.tar.bz2
Remove TabContents from TabStripModel.
BUG=107201 TEST=no visible change Review URL: https://chromiumcodereview.appspot.com/11547010 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@172960 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/browser/automation')
-rw-r--r--chrome/browser/automation/testing_automation_provider.cc21
1 files changed, 10 insertions, 11 deletions
diff --git a/chrome/browser/automation/testing_automation_provider.cc b/chrome/browser/automation/testing_automation_provider.cc
index a5995a8..16e6c8b 100644
--- a/chrome/browser/automation/testing_automation_provider.cc
+++ b/chrome/browser/automation/testing_automation_provider.cc
@@ -114,7 +114,6 @@
#include "chrome/browser/ui/omnibox/omnibox_view.h"
#include "chrome/browser/ui/search_engines/keyword_editor_controller.h"
#include "chrome/browser/ui/startup/startup_types.h"
-#include "chrome/browser/ui/tab_contents/tab_contents.h"
#include "chrome/browser/view_type_utils.h"
#include "chrome/common/automation_constants.h"
#include "chrome/common/automation_events.h"
@@ -3547,8 +3546,8 @@ void TestingAutomationProvider::GetSavedPasswords(
namespace {
-// Get the TabContents from a dictionary of arguments.
-TabContents* GetTabContentsFromDict(const Browser* browser,
+// Get the WebContents from a dictionary of arguments.
+WebContents* GetWebContentsFromDict(const Browser* browser,
const DictionaryValue* args,
std::string* error_message) {
int tab_index;
@@ -3557,13 +3556,13 @@ TabContents* GetTabContentsFromDict(const Browser* browser,
return NULL;
}
- TabContents* tab_contents =
- browser->tab_strip_model()->GetTabContentsAt(tab_index);
- if (!tab_contents) {
+ WebContents* web_contents =
+ browser->tab_strip_model()->GetWebContentsAt(tab_index);
+ if (!web_contents) {
*error_message = StringPrintf("No tab at index %d.", tab_index);
return NULL;
}
- return tab_contents;
+ return web_contents;
}
} // namespace
@@ -3573,9 +3572,9 @@ void TestingAutomationProvider::FindInPage(
DictionaryValue* args,
IPC::Message* reply_message) {
std::string error_message;
- TabContents* tab_contents =
- GetTabContentsFromDict(browser, args, &error_message);
- if (!tab_contents) {
+ WebContents* web_contents =
+ GetWebContentsFromDict(browser, args, &error_message);
+ if (!web_contents) {
AutomationJSONReply(this, reply_message).SendError(error_message);
return;
}
@@ -3603,7 +3602,7 @@ void TestingAutomationProvider::FindInPage(
SendError("Must include find_next boolean.");
return;
}
- SendFindRequest(tab_contents->web_contents(),
+ SendFindRequest(web_contents,
true,
search_string,
forward,